/*	
								Figure 10
				The Gains from Trade and Household Income
*/

clear
set more off

********************************************************************************

*Set macros

global user = "Nicolas"	

		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		global figures    "C:\Users\wb309100\Dropbox\TPJIE\HIT\paper"
		}
			
		if "$user" == "Nicolas" {			
		cd  "C:\Users\wb530118\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb530118\Dropbox\TPJIE"
		global results "C:\Users\wb530118\Dropbox\Final Submission\HIT\results"
		global figures    "C:\Users\wb530118\Dropbox\Final Submission\HIT\submission\Final Submission\Figures"
		}
		
********************************************************************************

set scheme s2mono

use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace

		
	* Aggregating expenditure and income shares
		egen agexp=rsum(share_exp_11* share_exp_12*)
		egen manexp=rsum(share_exp_2*)
		egen servexp=rsum(share_exp_3*)
		egen otherexp=rsum(share_exp_4*)
		gen homeexp=1-agexp-manexp-servexp-otherexp
		
		egen aginc=rsum(share_inc_11* share_inc_12*)
		egen wageinc=rsum(share_inc_2*)
		egen nfeinc=rsum(share_inc_3*)
		egen otherinc=rsum(share_inc_4*)
		gen homeinc=1-aginc-wageinc-nfeinc-otherinc
		
		tabstat aginc wageinc nfeinc otherinc homeinc, stats(mean sd n min p10 q p90 max)
		
gen lpce=log(yreal0)



*****************************************************************************************************		
*  	SCENARIO III: Impact of eliminating agricultural tariffs (not accounting for changes in wages)		
*****************************************************************************************************	
	
	set scheme s2mono

	* list of exp_codes
		global 	exp_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	exp_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"
	
	* list of inc_codes
		global 	inc_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	inc_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

		
	* Welfare change
	
	* consumption gains
		foreach i in $exp_staplefood $exp_nonstaplefood {
		 * Price change
			ge dp_exp_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_exp_`i')
		 * Attendant change in welfare	
			* note minus sign in front of gains!
			ge cg_`i'=-share_exp_`i'*dp_exp_`i'
			}
		 * Aggregating across products		
			egen ag_cg=rsum(cg_*)
	*income losses	
		foreach i in $inc_staplefood $inc_nonstaplefood {
			* price change
			ge dp_inc_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_inc_`i')
			* income gains
			ge il_`i'=share_inc_`i'*dp_inc_`i'
			}
		* Aggregating across products		
			egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il
		
	* Sdev
		egen sd_gains=sd(ag_gains), by(ciso)
		
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains=ag_gains if b20==1
		ge t20ag_gains=ag_gains if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains=mean(b20ag_gains) , by(ciso)
		egen mt20ag_gains=mean(t20ag_gains) , by(ciso)
		ge p_bias=mb20ag_gains-t20ag_gains
		
		label var ag_gains "Gains from agricultural trade liberalization"
		label var ag_il  "Consumption gains from agricultural trade liberalization"
		label var ag_il  "Income gains from agricultural trade liberalization"
		

gen loggdppc=log(gdppc)


* FIGURE: GAINS VS GDP PER CAPITA		
ge ag_gain100=100*ag_gain

		twoway (scatter ag_gain100 lpce, msize(vtiny) mcol(gray)) || /*
			*/  (lpoly ag_gain100 lpce,  lwidth(thick) lcol(black))  /*
			*/	   ,  ytitle("gains") /*
			*/     xtitle("log per capita expenditure") /*
			*/     legend(off)  /*
			*/     ylabel(, nogrid) /*
			*/     graphregion(color(white)) bgcolor(white)  /*
			*/ 	   plotregion(fcolor(white)) graphregion(fcolor(white)) 
	
	graph export "$figures\ArtucPortoRijkers Fig 10.eps", as(eps) replace

