
/*	
									Figure 7
			Map: The Developing World Distribution of the Gains from Trade
*/

clear
set more off

********************************************************************************

*Set macros

global user = "Nicolas"	

		
	
		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		global figures    "C:\Users\wb309100\Dropbox\TPJIE\HIT\paper"
		}
			
		if "$user" == "Nicolas" {			
		cd  "C:\Users\wb530118\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb530118\Dropbox\TPJIE"
		global results "C:\Users\wb530118\Dropbox\Final Submission\HIT\results"
		global figures    "C:\Users\wb530118\Dropbox\Final Submission\HIT\submission\Final Submission\Figures"
		}
		
********************************************************************************


/*
NOTE

Install map ado files if not available:

(1) to use grmap command

grmap, activate
 
(2) to use spmap command

ssc install spmap
ssc install shp2dta			

shapefile: worldcoord.dta

*/



*Load map metadata
use "${mainfolder}\HIT\submission\Resubmission\auxiliarydata\mapdata.dta" , clear 
*Save temp
replace country = "Ivory Coast" in 41
tempfile tmp
save `tmp'
sort country

****
****CALCULATE GAINS
****

use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace	

replace country="Central African Republic" if ciso=="CAR"
replace country="Ivory Coast" if ciso=="CIV"
cap drop _merge


gen quintile=recode(rank,20,40,60,80,100)

		
	* Aggregating expenditure and income shares
		egen agexp=rsum(share_exp_11* share_exp_12*)
		egen manexp=rsum(share_exp_2*)
		egen servexp=rsum(share_exp_3*)
		egen otherexp=rsum(share_exp_4*)
		gen homeexp=1-agexp-manexp-servexp-otherexp
		
		egen aginc=rsum(share_inc_11* share_inc_12*)
		egen wageinc=rsum(share_inc_2*)
		egen nfeinc=rsum(share_inc_3*)
		egen otherinc=rsum(share_inc_4*)
		gen homeinc=1-aginc-wageinc-nfeinc-otherinc
		
		tabstat aginc wageinc nfeinc otherinc homeinc, stats(mean sd n min p10 q p90 max)
		
gen lpce=log(yreal0)



*****************************************************************************************************		
*  	SCENARIO III: Impact of eliminating agricultural tariffs (not accounting for changes in wages)		
*****************************************************************************************************	


	* list of exp_codes
		global 	exp_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	exp_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"
	
	* list of inc_codes
		global 	inc_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	inc_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

		
* Welfare change
	
	* consumption gains
		foreach i in $exp_staplefood $exp_nonstaplefood {
		 * Price change
			ge dp_exp_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_exp_`i')
		 * Attendant change in welfare	
			* note minus sign in front of gains!
			ge cg_`i'=-share_exp_`i'*dp_exp_`i'
			}
		 * Aggregating across products		
			egen ag_cg=rsum(cg_*)
	*income losses	
		foreach i in $inc_staplefood $inc_nonstaplefood {
			* price change
			ge dp_inc_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_inc_`i')
			* income gains
			ge il_`i'=share_inc_`i'*dp_inc_`i'
			}
		* Aggregating across products		
			egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il
		
	* SD gains
		egen sd_gains=sd(ag_gains), by(ciso)
		
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains=ag_gains if b20==1
		ge t20ag_gains=ag_gains if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains=mean(b20ag_gains) , by(ciso)
		egen mt20ag_gains=mean(t20ag_gains) , by(ciso)
		ge p_bias=mb20ag_gains-mt20ag_gains
		
		label var ag_gains "Gains from agricultural trade liberalization"
		label var sd_gains "Standard deviation of gains from agricultural trade liberalization"
		label var ag_il  "Consumption gains from agricultural trade liberalization"
		label var ag_il  "Income gains from agricultural trade liberalization"

	*Keep 1 obs by country
	egen mag_gains=mean(ag_gains), by(ciso)
	
	keep if rank==1
	
	*Merge maps metadata
	merge 1:1 country using `tmp', keepus(country continent id)
	*replace mag_gains=. if !(_m == 3 | country == "Comoros")
	keep if _m == 3 | country == "Comoros"
	drop _m
 
/**** MAPS ****/
/** Average gains from trade **/

replace mag_gains=100*mag_gains
sum mag_gains, d

grmap mag_gains using ${mainfolder}\HIT\submission\Resubmission\auxiliarydata\worldcoor.dta  , id(id) ///
fcolor(black*0 black*0.1 black*0.2 black*0.3 black*0.4 black*0.5 black*0.6 black*0.7 black*0.8 black*0.9 black) ///
ocolor(black ..) ndocolor(black) ndfcolor(black*0.1) legend(position(7)) clmethod(custom) ///
clbreaks(-4 -3 -2 -1 0 1 2 3 4 5 6 7)

/*

{ // Show/Hide
gen NAME=""
	replace NAME="Armenia" if country=="Armenia"
	replace NAME="Azerbaijan" if country=="Azerbaijan"
	replace NAME="Bangladesh" if country=="Bangladesh"
	replace NAME="Benin" if country=="Benin"
	replace NAME="Bhutan" if country=="Bhutan"
	replace NAME="Bolivia" if country=="Bolivia"
	replace NAME="Burkina Faso" if country=="Burkina Faso"
	replace NAME="Burundi" if country=="Burundi"
	replace NAME="Cambodia" if country=="Cambodia"
	replace NAME="Cameroon" if country=="Cameroon"
	replace NAME="Central African Republic" if country=="Central African Republic"
	replace NAME="Comoros" if country=="Comoros"
	replace NAME="Ecuador" if country=="Ecuador"
	replace NAME="Egypt" if country=="Egypt, Arab Rep."
	replace NAME="Ethiopia" if country=="Ethiopia"
	replace NAME="Gambia" if country=="Gambia, The"
	replace NAME="Georgia" if country=="Georgia"
	replace NAME="Ghana" if country=="Ghana"
	replace NAME="Guatemala" if country=="Guatemala"
	replace NAME="Guinea" if country=="Guinea"
	replace NAME="Guinea-Bissau" if country=="Guinea-Bissau"
	replace NAME="Indonesia" if country=="Indonesia"
	replace NAME="Iraq" if country=="Iraq"
	replace NAME="Cote d'Ivoire" if country=="Ivory Coast"
	replace NAME="Jordan" if country=="Jordan"
	replace NAME="Kenya" if country=="Kenya"
	replace NAME="Kyrgyzstan" if country=="Kyrgyz Republic"
	replace NAME="Liberia" if country=="Liberia"
	replace NAME="Madagascar" if country=="Madagascar"
	replace NAME="Malawi" if country=="Malawi"
	replace NAME="Mali" if country=="Mali"
	replace NAME="Mauritania" if country=="Mauritania"
	replace NAME="Republic of Moldova" if country=="Moldova"
	replace NAME="Mongolia" if country=="Mongolia"
	replace NAME="Mozambique" if country=="Mozambique"
	replace NAME="Nepal" if country=="Nepal"
	replace NAME="Nicaragua" if country=="Nicaragua"
	replace NAME="Niger" if country=="Niger"
	replace NAME="Nigeria" if country=="Nigeria"
	replace NAME="Pakistan" if country=="Pakistan"
	replace NAME="Papua New Guinea" if country=="Papua New Guinea"
	replace NAME="Rwanda" if country=="Rwanda"
	replace NAME="Sierra Leone" if country=="Sierra Leone"
	replace NAME="South Africa" if country=="South Africa"
	replace NAME="Sri Lanka" if country=="Sri Lanka"
	replace NAME="Tajikistan" if country=="Tajikistan"
	replace NAME="United Republic of Tanzania" if country=="Tanzania"
	replace NAME="Togo" if country=="Togo"
	replace NAME="Uganda" if country=="Uganda"
	replace NAME="Ukraine" if country=="Ukraine"
	replace NAME="Uzbekistan" if country=="Uzbekistan"
	replace NAME="Viet Nam" if country=="Vietnam"
	replace NAME="Yemen" if country=="Yemen, Rep."
	replace NAME="Zambia" if country=="Zambia"
}

keep NAME mag_gains
*/

graph export "${figures}/ArtucPortoRijkers Fig 7.eps", as(eps) replace
/*
graph export "${figures}/figure7.png", as(png) replace
graph export "${figures}/figure7.pdf", as(pdf) replace
*/

