/*	
						Table 3
	The Gains From Agricultural Tariff Liberalization
					Aggregated Data

*/

clear
set more off

********************************************************************************

*Set macros


global user = "BobWork"	
		

		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		}

		
********************************************************************************

if "$user" == "BobWork"  {
use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace	
}


drop _merge
sort ciso
merge ciso using "$mainfolder\Data\HIT\auxiliarydata\ag tariffs.dta"



gen quintile=recode(rank,20,40,60,80,100)

		
	* Aggregating expenditure and income shares

		egen stapleag_exp=rsum(share_exp_11*)
		egen nstapleag_exp=rsum(share_exp_12*)
		
		egen stapleag_inc=rsum(share_inc_11*)
		egen nstapleag_inc=rsum(share_inc_12*)

gen lpce=log(yreal0)

	
	* Welfare change
	
	* consumption gains
		 
		ge cg_stapleag=stapleag_exp*(t_stapleag/(1+t_stapleag))
		ge cg_nstapleag=nstapleag_exp*(t_nstapleag/(1+t_nstapleag))
			
		egen ag_cg=rsum(cg_*)

	*income losses	
		ge il_stapleag=-stapleag_inc*(t_stapleag/(1+t_stapleag))
		ge il_nstapleag=-nstapleag_inc*(t_nstapleag/(1+t_nstapleag))
			
		egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il

	* SD gains
		egen sd_gains=sd(ag_gains), by(ciso)

		
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains=ag_gains if b20==1
		ge t20ag_gains=ag_gains if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains=mean(b20ag_gains) , by(ciso)
		egen mt20ag_gains=mean(t20ag_gains) , by(ciso)
		ge p_bias=mb20ag_gains-mt20ag_gains
		

	* Table with results	
		sort country
		tabstat ag_gains sd_gains ag_cg ag_il p_bias b20ag_gains t20ag_gains , by(country) format(%8.3f) save
		

    matrix define B=r(StatTotal)*100

forvalues i=1(1)54 {
  matrix define A`i'=r(Stat`i')
  local name`i'=r(name`i')
  }

  
  
		
*The following loops saves the table in .Tex

forvalues i=1(1)54 {
  matrix define A`i'=r(Stat`i')
  local name`i'=r(name`i')
  }

qui { 
set linesize 255
capture log close
log using "$results\table3.tex", text replace

no di "\begin{tabular}"
no di "{lccccccc}\hline\hline"
no di " Country & Aggregate & Standard Dev & Consumption & Income  & Pro-Poor & Gains & Gains \\"
no di "         & Gains     & Gains 	   & Effects     & Effects & Bias     & Poor  & Rich \\"
*no di " & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline"
no di "\hline"
no di "\\"


no di "Developing world", _c
* Columns
  forvalues c=1(1)7{
    no di "&" %9.2f B[1,`c'], _c
    }
  no di "\\"

* Lines
forvalues i=1(1)54 {
no di "`name`i''", _c

* Columns
  forvalues c=1(1)7{
    matrix define A=A`i'*100
    no di "&" %9.2f A[1,`c'], _c
    }
  no di "\\"

}
no di "\hline"
no di "\end{tabular}"
log close
}  
  
  
  
  
  
  
  