/*	
						Table 4
	Bias when using aggregated instead of disaggregated ata

*/

clear
set more off

********************************************************************************

*Set macros

*global user = "nicolas"	
global user = "BobWork"	
		

					
		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		}
			
********************************************************************************

if "$user" == "BobWork"  {
use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace	
}


drop _merge
sort ciso
merge ciso using "$mainfolder\Data\HIT\auxiliarydata\ag tariffs.dta"

gen quintile=recode(rank,20,40,60,80,100)

********************************************************
* STEP 1:  CALCULATE DISAGGREGATED GAINS
********************************************************
	* list of exp_codes
		global 	exp_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	exp_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"
	
	* list of inc_codes
		global 	inc_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	inc_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

		
* Welfare change
	
	* consumption gains
		foreach i in $exp_staplefood $exp_nonstaplefood {
		 * Price change
			ge dp_exp_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_exp_`i')
		 * Attendant change in welfare	
			* note minus sign in front of gains!
			ge cg_`i'=-share_exp_`i'*dp_exp_`i'
			}
		 * Aggregating across products		
			egen ag_cg=rsum(cg_*)
	*income losses	
		foreach i in $inc_staplefood $inc_nonstaplefood {
			* price change
			ge dp_inc_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_inc_`i')
			* income gains
			ge il_`i'=share_inc_`i'*dp_inc_`i'
			}
		* Aggregating across products		
			egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il
		
	* SD gains
		egen sd_gains=sd(ag_gains), by(ciso)
		
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains=ag_gains if b20==1
		ge t20ag_gains=ag_gains if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains=mean(b20ag_gains) , by(ciso)
		egen mt20ag_gains=mean(t20ag_gains) , by(ciso)
		ge p_bias=mb20ag_gains-mt20ag_gains
		
		label var ag_gains "Gains from agricultural trade liberalization"
		label var sd_gains "Standard deviation of gains from agricultural trade liberalization"
		label var ag_il  "Consumption gains from agricultural trade liberalization"
		label var ag_il  "Income gains from agricultural trade liberalization"

	*Save table with results	
		tabstat ag_gains sd_gains ag_cg ag_il p_bias b20ag_gains t20ag_gains , by(country) format(%8.2f) save

*******************
* STEP 2: CALCULATE AGGREGATE GAINS
		
	* Aggregating expenditure and income shares

		egen stapleag_exp=rsum(share_exp_11*)
		egen nstapleag_exp=rsum(share_exp_12*)

		egen stapleag_inc=rsum(share_inc_11*)
		egen nstapleag_inc=rsum(share_inc_12*)


		gen lpce=log(yreal0)

	
	* Aggregate Welfare change
	
	* consumption gains
		 
		ge Acg_stapleag=stapleag_exp*(t_stapleag/(1+t_stapleag))
		ge Acg_nstapleag=nstapleag_exp*(t_nstapleag/(1+t_nstapleag))
			
		egen Aag_cg=rsum(Acg_*)

	*income losses	
		ge Ail_stapleag=-stapleag_inc*(t_stapleag/(1+t_stapleag))
		ge Ail_nstapleag=-nstapleag_inc*(t_nstapleag/(1+t_nstapleag))
			
		egen Aag_il=rsum(Ail_*)
			
	* Total
		ge Aag_gains=Aag_cg+Aag_il

	* SD gains
		egen Asd_gains=sd(Aag_gains), by(ciso)

		
		* for table in HIT paper
		*ge b20=(rank<21)
		*ge t20=(rank>80)
		ge b20Aag_gains=Aag_gains if b20==1
		ge t20Aag_gains=Aag_gains if t20==1
		
		* calculate poverty bias
		egen mb20Aag_gains=mean(b20Aag_gains) , by(ciso)
		egen mt20Aag_gains=mean(t20Aag_gains) , by(ciso)
		ge Ap_bias=mb20Aag_gains-mt20Aag_gains
		
	* Table with results	
		sort country
		tabstat Aag_gains Asd_gains Aag_cg Aag_il b20Aag_gains t20Aag_gains Ap_bias, by(country) format(%8.3f) save
		

		
**************************************************
* STEP 3: Calculate BIASES		
**************************************************


ge Ab20ag_gains=b20Aag_gains
ge At20ag_gains=t20Aag_gains

foreach var of varlist ag_gains sd_gains ag_cg ag_il p_bias b20ag_gains t20ag_gains  {
egen B_`var'=mean(A`var'-`var'), by(ciso)
replace B_`var'=100*B_`var'
label var B_`var' "aggregation bias `var'"
egen AB_`var'=mean(abs(A`var'-`var')), by(ciso)
replace AB_`var'=100*AB_`var'
label var AB_`var' "absolute aggregation bias `var'"		
egen P_`var'=sum((B_`var'>0))
replace P_`var'=P_`var'/100
egen N_`var'=sum((B_`var'<0))
replace N_`var'=N_`var'/100
egen minB_`var'=min(B_`var')
egen maxB_`var'=max(B_`var')
}		
		
		
tabstat B_ag_gains P_ag_gains minB_ag_gains maxB_ag_gains AB_ag_gains		
		
	
matrix B = J(6,7,0)


local j=0
foreach var of varlist ag_gains sd_gains ag_cg ag_il p_bias b20ag_gains t20ag_gains  {
local j=`j'+1
local i=0	
foreach var of varlist 	B_`var' P_`var' N_`var' minB_`var' maxB_`var' AB_`var' {		
    local i=`i'+1
    di `i'
su `var'
matrix B[`i',`j']=r(mean)
}
}

matrix list B 

*Create sub-matrices by row for table loop

forval i=1(1)6 {

mat A`i'=B[`i'..`i',.]

}
	
	
		
*The following loops save the table in .Tex

*Line names for table

local name1 "Average bias"	
local name2 "Countries with positive bias"
local name3 "Countries with negative bias"
local name4 "Minimum bias"
local name5 "Maximum bias"	
local name6 "Average absolute bias"


qui { 
set linesize 255
capture log close
log using "$results\table4.tex", text replace

no di "\begin{tabular}"
no di "{lccccccc}\hline\hline"
no di " 	 & Aggregate & St.Dev.  & Consumption & Income  & Pro-Poor & Gains & Gains \\"
no di "         & Gains     & Gains  & Effects     & Effects & Bias     & Poor  & Rich \\"

no di "\hline"
no di "\\"

 
* Lines
forvalues i=1(1)6 {
no di "`name`i''", _c

* Columns
  forvalues c=1(1)7{
    matrix define A=A`i'
    no di "&" %9.2f A[1,`c'], _c
    }
  no di "\\"

}
no di "\hline"
no di "\end{tabular}"
log close
}

  
  