/*	
						Table 5
	The Gains From Agricultural Tariff Liberalization
					Across Commodities
						Vietnam

*/

clear
set more off

********************************************************************************

*Set macros

global user = "BobWork"	
		

					
		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		}
			

		
********************************************************************************

if "$user" == "BobWork" {
use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace	
}

gen quintile=recode(rank,20,40,60,80,100)

	* Aggregating expenditure and income shares
		egen agexp=rsum(share_exp_11* share_exp_12*)
		egen manexp=rsum(share_exp_2*)
		egen servexp=rsum(share_exp_3*)
		egen otherexp=rsum(share_exp_4*)
		gen homeexp=1-agexp-manexp-servexp-otherexp
		
		egen aginc=rsum(share_inc_11* share_inc_12*)
		egen wageinc=rsum(share_inc_2*)
		egen nfeinc=rsum(share_inc_3*)
		egen otherinc=rsum(share_inc_4*)
		gen homeinc=1-aginc-wageinc-nfeinc-otherinc
		
		tabstat aginc wageinc nfeinc otherinc homeinc, stats(mean sd n min p10 q p90 max)
		
gen lpce=log(yreal0)



*****************************************************************************************************		
*  	SCENARIO III: Impact of eliminating agricultural tariffs (not accounting for changes in wages)		
*****************************************************************************************************	


	* list of exp_codes
		global 	exp_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	exp_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"
	
	* list of inc_codes
		global 	inc_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	inc_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

		
	* Welfare change
	
	* consumption gains
		foreach i in $exp_staplefood $exp_nonstaplefood {
		 * Price change
			ge dp_exp_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_exp_`i')
		 * Attendant change in welfare	
			* note minus sign in front of gains!
			ge cg_`i'=-share_exp_`i'*dp_exp_`i'
			}
		 * Aggregating across products		
			egen ag_cg=rsum(cg_*)
	*income losses	
		foreach i in $inc_staplefood $inc_nonstaplefood {
			* price change
			ge dp_inc_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_inc_`i')
			* income gains
			ge il_`i'=share_inc_`i'*dp_inc_`i'
			}
		* Aggregating across products		
			egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il
		
		* SD gains
		egen sd_gains=sd(ag_gains), by(ciso)
			
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains=ag_gains if b20==1
		ge t20ag_gains=ag_gains if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains=mean(b20ag_gains) , by(ciso)
		egen mt20ag_gains=mean(t20ag_gains) , by(ciso)
		ge p_bias=mb20ag_gains-t20ag_gains
		
		label var ag_gains "Gains from agricultural trade liberalization"
		label var ag_il  "Consumption gains from agricultural trade liberalization"
		label var ag_il  "Income gains from agricultural trade liberalization"
		

		*Keep only Vietnam data
		keep if ciso=="VNM"

foreach i in $exp_staplefood $exp_nonstaplefood {
	* SD
	ge ag_`i'=cg_`i'+il_`i'
	egen sd_`i'=sd(ag_`i')
	*Cons Effects for b20
	ge aux=cg_`i'*b20
	egen cgb20_`i'=mean(aux) if b20==1
	drop aux
	*Cons Effects for t20
	ge aux=cg_`i'*t20
	egen cgt20_`i'=mean(aux) if t20==1
	drop aux
	*Inc Effects for b20
	ge aux=il_`i'*b20
	egen ilb20_`i'=mean(aux) if b20==1
	drop aux
	*Inc Effects for t20
	ge aux=il_`i'*t20
	egen ilt20_`i'=mean(aux) if t20==1
	drop aux
	}

	*Create variables for the table
	keep cg_*  il_* sd_* cgb20_* cgt20_* ilb20_* ilt20_*

	collapse (mean) cg_* il_* sd_* cgb20_* cgt20_* ilb20_* ilt20_*

	gen i=1
	reshape long cg_ il_ sd_ cgb20_ cgt20_ ilb20_ ilt20_, i(i) j(good)
	drop i
	rename cg_ cg
	rename il_ il
	rename sd_ sd
	rename cgb20_ cgb20
	rename cgt20_ cgt20
	rename ilb20_ ilb20
	rename ilt20_ ilt20

	replace cg=cg*100
	replace il=il*100
	replace sd=sd*100
	replace cgb20=cgb20*100
	replace cgt20=cgt20*100
	replace ilb20=ilb20*100
	replace ilt20=ilt20*100

	gen g=cg+il
	gen g_poor=cgb20+ilb20
	gen g_rich=cgt20+ilt20

	gen bias=g_poor-g_rich
	gen bias_c=cgb20-cgt20
	gen bias_i=ilb20-ilt20

	*Variable with name of the good
	gen goodname="."
	replace goodname="Corn" in 1
	replace goodname="Wheat" in 2
	replace goodname="Rice" in 3
	replace goodname="Other cereals" in 4
	replace goodname="Beans" in 5
	replace goodname="Other" in 6
	replace goodname="Banana" in 7
	replace goodname="Grapes" in 8
	replace goodname="Citrus" in 9
	replace goodname="Apples" in 10
	replace goodname="Other fruit" in 11
	replace goodname="Tomato" in 12
	replace goodname="Potato" in 13
	replace goodname="Greens" in 14
	replace goodname="Other vegetables" in 15		
	replace goodname="Vegetable oils" in 16
	replace goodname="Animal fats" in 17
	replace goodname="Other oils/fats" in 18
	replace goodname="Fish" in 19
	replace goodname="Shrimp" in 20
	replace goodname="Other crustaceans" in 21
	replace goodname="Pork" in 22
	replace goodname="Beef" in 23
	replace goodname="Poultry" in 24
	replace goodname="Other meat" in 25
	replace goodname="Milk" in 26
	replace goodname="Eggs" in 27
	replace goodname="Cheese" in 28
	replace goodname="Other Dairy" in 29
	replace goodname="Other staple foods" in 30
	replace goodname="Other Processed Food	" in 31			
	replace goodname="Wine" in 32
	replace goodname="Beer" in 33
	replace goodname="Other alcohol" in 34
	replace goodname="Cigarettes" in 35
	replace goodname="Other tobacco" in 36
	replace goodname="Soya" in 37
	replace goodname="Other oil seeds" in 38
	replace goodname="Cloves" in 39
	replace goodname="Pepper" in 40
	replace goodname="Vanilla" in 41
	replace goodname="Saffron" in 42
	replace goodname="Qat (chat)" in 43
	replace goodname="Other Spices" in 44
	replace goodname="Coffee" in 45
	replace goodname="Tea" in 46
	replace goodname="Cocoa" in 47
	replace goodname="Cashew" in 48
	replace goodname="Coconut" in 49
	replace goodname="Other nuts" in 50
	replace goodname="Cotton" in 51
	replace goodname="Sugar" in 52
	replace goodname="Other non-staple" in 53				

	*Table with results
	tabstat g sd cg il  bias g_poor g_rich , by(goodname) format(%8.2f) stat(sum) save
	
	*Save in matrix
    matrix define B=r(StatTotal)

*The following loops save the table in .Tex
forvalues i=1(1)53 {
  matrix define A`i'=r(Stat`i')
  local name`i'=r(name`i')
  }

qui { 
set linesize 255
capture log close
log using "$results\table5.tex", text replace

no di "\begin{tabular}"
no di "{lccccccc}\hline\hline"
no di " Product & Aggregate & St.Dev.  & Consumption & Income  & Pro-Poor & Gains & Gains \\"
no di "         & Gains     & Gains  & Effects     & Effects & Bias     & Poor  & Rich \\"
*no di " & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline"
no di "\hline"
no di "\\"


no di "Aggregate", _c
* Columns
  forvalues c=1(1)7{
    no di "&" %9.2f B[1,`c'], _c
    }
  no di "\\"

* Lines
forvalues i=1(1)53 {
no di "`name`i''", _c

* Columns
  forvalues c=1(1)7{
    matrix define A=A`i'
    no di "&" %9.2f A[1,`c'], _c
    }
  no di "\\"

}
no di "\hline"
no di "\end{tabular}"
log close
}


