/*	
						Table 6
		The Gains From Cereals Tariff Liberalization

*/

clear
set more off

********************************************************************************

*Set macros


global user = "BobWork"
		
	
		if "$user" == "BobWork" {			
		cd  "C:\Users\wb309100\Dropbox\TPJIE\"
		global mainfolder "C:\Users\wb309100\Dropbox\TPJIE\"
		global results "C:\Users\wb309100\Dropbox\TPJIE\HIT\results"
		}
			

		
********************************************************************************

if "$user" == "BobWork" | "$user" == "nicolas" {
use "$mainfolder\Data\HIT\hhsurveys_collapsed\col_hh_world.dta",  replace	
}


gen quintile=recode(rank,20,40,60,80,100)

		
	* Aggregating expenditure and income shares
		egen agexp=rsum(share_exp_11* share_exp_12*)
		egen manexp=rsum(share_exp_2*)
		egen servexp=rsum(share_exp_3*)
		egen otherexp=rsum(share_exp_4*)
		gen homeexp=1-agexp-manexp-servexp-otherexp
		
		egen aginc=rsum(share_inc_11* share_inc_12*)
		egen wageinc=rsum(share_inc_2*)
		egen nfeinc=rsum(share_inc_3*)
		egen otherinc=rsum(share_inc_4*)
		gen homeinc=1-aginc-wageinc-nfeinc-otherinc
		
		tabstat aginc wageinc nfeinc otherinc homeinc, stats(mean sd n min p10 q p90 max)
		
gen lpce=log(yreal0)



*****************************************************************************************************		
*  	SCENARIO III: Impact of eliminating agricultural tariffs ONLY in Cereals (not accounting for changes in wages)		
*****************************************************************************************************	


	* list of exp_codes
		global 	exp_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	exp_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

	
	* list of inc_codes
		global 	inc_staplefood 		"1111 1112 1113 1114 1121 1122 1131 1132 1133 1134 1135 1141 1142 1143 1144 1151 1152 1153 1161 1162 1163 1171 1172 1173 1174 1181 1182 1183 1184 1191 1192"
		global 	inc_nonstaplefood   "1211 1212 1213 1221 1222 1231 1232 1241 1242 1243 1244 1245 1246 1251 1252 1253 1261 1262 1263 1271 1281 1282"

		
	* Welfare change
	
	* consumption gains
		foreach i in $exp_staplefood $exp_nonstaplefood {
		 * Price change
			ge dp_exp_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_exp_`i')
		 * Attendant change in welfare	
			* note minus sign in front of gains!
			ge cg_`i'=-share_exp_`i'*dp_exp_`i'
			}
		 * Aggregating across products		
			egen ag_cg=rsum(cg_*)
	*income losses	
		foreach i in $inc_staplefood $inc_nonstaplefood {
			* price change
			ge dp_inc_`i'=-wa_tariff_exp_`i'/(1+wa_tariff_inc_`i')
			* income gains
			ge il_`i'=share_inc_`i'*dp_inc_`i'
			}
		* Aggregating across products		
			egen ag_il=rsum(il_*)
			
	* Total
		ge ag_gains=ag_cg+ag_il
		gen ag_cg_cereals=cg_1111+cg_1112+cg_1113+cg_1114
		gen ag_il_cereals=il_1111+il_1112+il_1113+il_1114
		gen ag_gains_cereals=ag_cg_cereals+ag_il_cereals

		* SD gains
		egen sd_gains_cereals=sd(ag_gains_cereals), by(ciso)
		
		* for table in HIT paper
		ge b20=(rank<21)
		ge t20=(rank>80)
		ge b20ag_gains_cereals=ag_gains_cereals if b20==1
		ge t20ag_gains_cereals=ag_gains_cereals if t20==1
		
		* calculate poverty bias
		egen mb20ag_gains_cereals=mean(b20ag_gains_cereals) , by(ciso)
		egen mt20ag_gains_cereals=mean(t20ag_gains_cereals) , by(ciso)
		ge p_bias_cereals=mb20ag_gains_cereals-t20ag_gains_cereals

		
	* Save table with results	
		tabstat ag_gains_cereals sd_gains_cereals ag_cg_cereals ag_il_cereals b20ag_gains_cereals t20ag_gains_cereals p_bias_cereals, by(country) format(%8.3f) save

   * Create a matrix with the previous results x100
		matrix define B=r(StatTotal)*100

	*The following loops save the table in .Tex
forvalues i=1(1)54 {
  matrix define A`i'=r(Stat`i')
  local name`i'=r(name`i')
  }

qui { 
set linesize 255
capture log close
log using "$results\table6.tex", text replace

no di "\begin{tabular}"
no di "{lcccccc}\hline\hline"
no di " Country & Aggregate & Standard Deviation & Consumption & Income  & Pro-Poor & Gains & Gains \\"
no di "         & Gains     & Gains     		 & Effects     & Effects & Bias     & Poor  & Rich \\"
*no di " & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline"
no di "\hline"
no di "\\"


no di "Developing world", _c
* Columns
  forvalues c=1(1)7{
    no di "&" %9.2f B[1,`c'], _c
    }
  no di "\\"

* Lines
forvalues i=1(1)54 {
no di "`name`i''", _c

* Columns
  forvalues c=1(1)7{
    matrix define A=A`i'*100
    no di "&" %9.2f A[1,`c'], _c
    }
  no di "\\"

}
no di "\hline"
no di "\end{tabular}"
log close
}
